Documentation
¶
Index ¶
- type Client
- type ListResourceGroupsOK
- type ListResourceGroupsParams
- func NewListResourceGroupsParams() *ListResourceGroupsParams
- func NewListResourceGroupsParamsWithContext(ctx context.Context) *ListResourceGroupsParams
- func NewListResourceGroupsParamsWithHTTPClient(client *http.Client) *ListResourceGroupsParams
- func NewListResourceGroupsParamsWithTimeout(timeout time.Duration) *ListResourceGroupsParams
- func (o *ListResourceGroupsParams) SetContext(ctx context.Context)
- func (o *ListResourceGroupsParams) SetHTTPClient(client *http.Client)
- func (o *ListResourceGroupsParams) SetTimeout(timeout time.Duration)
- func (o *ListResourceGroupsParams) WithContext(ctx context.Context) *ListResourceGroupsParams
- func (o *ListResourceGroupsParams) WithHTTPClient(client *http.Client) *ListResourceGroupsParams
- func (o *ListResourceGroupsParams) WithTimeout(timeout time.Duration) *ListResourceGroupsParams
- func (o *ListResourceGroupsParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type ListResourceGroupsReader
- type ListResourcesNotFound
- type ListResourcesOK
- type ListResourcesParams
- func (o *ListResourcesParams) SetContext(ctx context.Context)
- func (o *ListResourcesParams) SetGroup(group string)
- func (o *ListResourcesParams) SetHTTPClient(client *http.Client)
- func (o *ListResourcesParams) SetTimeout(timeout time.Duration)
- func (o *ListResourcesParams) WithContext(ctx context.Context) *ListResourcesParams
- func (o *ListResourcesParams) WithGroup(group string) *ListResourcesParams
- func (o *ListResourcesParams) WithHTTPClient(client *http.Client) *ListResourcesParams
- func (o *ListResourcesParams) WithTimeout(timeout time.Duration) *ListResourcesParams
- func (o *ListResourcesParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type ListResourcesReader
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for resources API
func New ¶
func New(transport runtime.ClientTransport, formats strfmt.Registry) *Client
New creates a new resources API client.
func (*Client) ListResourceGroups ¶
func (a *Client) ListResourceGroups(params *ListResourceGroupsParams) (*ListResourceGroupsOK, error)
ListResourceGroups List the root resource groups
func (*Client) ListResources ¶
func (a *Client) ListResources(params *ListResourcesParams) (*ListResourcesOK, error)
ListResources list resources API
func (*Client) SetTransport ¶
func (a *Client) SetTransport(transport runtime.ClientTransport)
SetTransport changes the transport on the client
type ListResourceGroupsOK ¶
type ListResourceGroupsOK struct {
Payload *models.ResponseListResources
}
ListResourceGroupsOK handles this case with default header values.
OK
func NewListResourceGroupsOK ¶
func NewListResourceGroupsOK() *ListResourceGroupsOK
NewListResourceGroupsOK creates a ListResourceGroupsOK with default headers values
func (*ListResourceGroupsOK) Error ¶
func (o *ListResourceGroupsOK) Error() string
type ListResourceGroupsParams ¶
type ListResourceGroupsParams struct {
Context context.Context
HTTPClient *http.Client
// contains filtered or unexported fields
}
ListResourceGroupsParams contains all the parameters to send to the API endpoint for the list resource groups operation typically these are written to a http.Request
func NewListResourceGroupsParams ¶
func NewListResourceGroupsParams() *ListResourceGroupsParams
NewListResourceGroupsParams creates a new ListResourceGroupsParams object with the default values initialized.
func NewListResourceGroupsParamsWithContext ¶
func NewListResourceGroupsParamsWithContext(ctx context.Context) *ListResourceGroupsParams
NewListResourceGroupsParamsWithContext creates a new ListResourceGroupsParams object with the default values initialized, and the ability to set a context for a request
func NewListResourceGroupsParamsWithHTTPClient ¶
func NewListResourceGroupsParamsWithHTTPClient(client *http.Client) *ListResourceGroupsParams
NewListResourceGroupsParamsWithHTTPClient creates a new ListResourceGroupsParams object with the default values initialized, and the ability to set a custom HTTPClient for a request
func NewListResourceGroupsParamsWithTimeout ¶
func NewListResourceGroupsParamsWithTimeout(timeout time.Duration) *ListResourceGroupsParams
NewListResourceGroupsParamsWithTimeout creates a new ListResourceGroupsParams object with the default values initialized, and the ability to set a timeout on a request
func (*ListResourceGroupsParams) SetContext ¶
func (o *ListResourceGroupsParams) SetContext(ctx context.Context)
SetContext adds the context to the list resource groups params
func (*ListResourceGroupsParams) SetHTTPClient ¶
func (o *ListResourceGroupsParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the list resource groups params
func (*ListResourceGroupsParams) SetTimeout ¶
func (o *ListResourceGroupsParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the list resource groups params
func (*ListResourceGroupsParams) WithContext ¶
func (o *ListResourceGroupsParams) WithContext(ctx context.Context) *ListResourceGroupsParams
WithContext adds the context to the list resource groups params
func (*ListResourceGroupsParams) WithHTTPClient ¶
func (o *ListResourceGroupsParams) WithHTTPClient(client *http.Client) *ListResourceGroupsParams
WithHTTPClient adds the HTTPClient to the list resource groups params
func (*ListResourceGroupsParams) WithTimeout ¶
func (o *ListResourceGroupsParams) WithTimeout(timeout time.Duration) *ListResourceGroupsParams
WithTimeout adds the timeout to the list resource groups params
func (*ListResourceGroupsParams) WriteToRequest ¶
func (o *ListResourceGroupsParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type ListResourceGroupsReader ¶
type ListResourceGroupsReader struct {
// contains filtered or unexported fields
}
ListResourceGroupsReader is a Reader for the ListResourceGroups structure.
func (*ListResourceGroupsReader) ReadResponse ¶
func (o *ListResourceGroupsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the received o.
type ListResourcesNotFound ¶
type ListResourcesNotFound struct {
Payload *models.ServerError
}
ListResourcesNotFound handles this case with default header values.
Not Found
func NewListResourcesNotFound ¶
func NewListResourcesNotFound() *ListResourcesNotFound
NewListResourcesNotFound creates a ListResourcesNotFound with default headers values
func (*ListResourcesNotFound) Error ¶
func (o *ListResourcesNotFound) Error() string
type ListResourcesOK ¶
type ListResourcesOK struct {
Payload *models.ResponseListResources
}
ListResourcesOK handles this case with default header values.
OK
func NewListResourcesOK ¶
func NewListResourcesOK() *ListResourcesOK
NewListResourcesOK creates a ListResourcesOK with default headers values
func (*ListResourcesOK) Error ¶
func (o *ListResourcesOK) Error() string
type ListResourcesParams ¶
type ListResourcesParams struct {
/*Group
Root level resources
*/
Group string
Context context.Context
HTTPClient *http.Client
// contains filtered or unexported fields
}
ListResourcesParams contains all the parameters to send to the API endpoint for the list resources operation typically these are written to a http.Request
func NewListResourcesParams ¶
func NewListResourcesParams() *ListResourcesParams
NewListResourcesParams creates a new ListResourcesParams object with the default values initialized.
func NewListResourcesParamsWithContext ¶
func NewListResourcesParamsWithContext(ctx context.Context) *ListResourcesParams
NewListResourcesParamsWithContext creates a new ListResourcesParams object with the default values initialized, and the ability to set a context for a request
func NewListResourcesParamsWithHTTPClient ¶
func NewListResourcesParamsWithHTTPClient(client *http.Client) *ListResourcesParams
NewListResourcesParamsWithHTTPClient creates a new ListResourcesParams object with the default values initialized, and the ability to set a custom HTTPClient for a request
func NewListResourcesParamsWithTimeout ¶
func NewListResourcesParamsWithTimeout(timeout time.Duration) *ListResourcesParams
NewListResourcesParamsWithTimeout creates a new ListResourcesParams object with the default values initialized, and the ability to set a timeout on a request
func (*ListResourcesParams) SetContext ¶
func (o *ListResourcesParams) SetContext(ctx context.Context)
SetContext adds the context to the list resources params
func (*ListResourcesParams) SetGroup ¶
func (o *ListResourcesParams) SetGroup(group string)
SetGroup adds the group to the list resources params
func (*ListResourcesParams) SetHTTPClient ¶
func (o *ListResourcesParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the list resources params
func (*ListResourcesParams) SetTimeout ¶
func (o *ListResourcesParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the list resources params
func (*ListResourcesParams) WithContext ¶
func (o *ListResourcesParams) WithContext(ctx context.Context) *ListResourcesParams
WithContext adds the context to the list resources params
func (*ListResourcesParams) WithGroup ¶
func (o *ListResourcesParams) WithGroup(group string) *ListResourcesParams
WithGroup adds the group to the list resources params
func (*ListResourcesParams) WithHTTPClient ¶
func (o *ListResourcesParams) WithHTTPClient(client *http.Client) *ListResourcesParams
WithHTTPClient adds the HTTPClient to the list resources params
func (*ListResourcesParams) WithTimeout ¶
func (o *ListResourcesParams) WithTimeout(timeout time.Duration) *ListResourcesParams
WithTimeout adds the timeout to the list resources params
func (*ListResourcesParams) WriteToRequest ¶
func (o *ListResourcesParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type ListResourcesReader ¶
type ListResourcesReader struct {
// contains filtered or unexported fields
}
ListResourcesReader is a Reader for the ListResources structure.
func (*ListResourcesReader) ReadResponse ¶
func (o *ListResourcesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the received o.